/* gcc_cpp */
/*

 '  CIRCLES.

O(n log n)

*/
#include <cstdio>
#include <algorithm>
#include <cstdlib>

using namespace std;

const char *infile="circles.dat";
const char *outfile="circles.sol";

const int maxN=10000;

struct circle_t {
	int x,y,r;
};

struct arc_t {
	int ind;
	int side; // 0 - left, 1 - right
	arc_t(int I=0,int S=0):ind(I),side(S) {}
};

struct event_t {
	int y,type,ind;
	event_t(int Y=0,int T=0,int I=0):y(Y),type(T),ind(I) {}
	bool operator<(const event_t &e)const {return y<e.y||y==e.y&&(type<e.type||type==e.type&&ind<e.ind);}
};

struct node_t {
	node_t *par,*left,*right;
	arc_t arc;
	int sz;
	void replace(node_t *s,node_t *d) {
		if(left==s)left=d;
		if(right==s)right=d;
	}
	node_t *next() {
		node_t *res;
		if(right) {
			for(res=right;res->left;res=res->left);
			return res;
		}
		else {
			for(res=this;res->par&&res==res->par->right;res=res->par);
			return res->par;
		}
	}
	node_t *prev() {
		node_t *res;
		if(left) {
			for(res=left;res->right;res=res->right);
			return res;
		}
		else {
			for(res=this;res->par&&res==res->par->left;res=res->par);
			return res->par;
		}
	}
};

circle_t c[maxN];
node_t *arcs[2][maxN];
event_t ev[2*maxN];
node_t nds[2*maxN];
int ndCnt;
node_t *root;
FILE *ifs=fopen(infile,"r");
FILE *ofs=fopen(outfile,"w");

#define SQR(x) ((x)*(x))
inline void intersect(int i1,int i2) {
	int d2=SQR(c[i1].x-c[i2].x)+SQR(c[i1].y-c[i2].y);
	if(i1!=i2&&d2<=SQR(c[i1].r+c[i2].r)&&d2>=SQR(c[i1].r-c[i2].r)) {
		fprintf(ofs,"%d %d\n",i1+1,i2+1);
		fclose(ifs);
		fclose(ofs);
		exit(0);
	}
}

inline node_t *NewNode(const arc_t &a) {nds[ndCnt].sz=1;nds[ndCnt].arc=a;return &nds[ndCnt++];}

bool ArcLeft(const arc_t &a,int x,int y) {
	if(a.side==0)x=2*c[a.ind].x-x;
	if(x<c[a.ind].x)return false;
	x-=c[a.ind].x;
	return SQR(x)>SQR(c[a.ind].r)-SQR(y-c[a.ind].y);
}

inline void InsertCircle(int i) {
	node_t *par,*nd,*n1,*n2;
	int s=-1;
	if(!root)par=0;
	else for(nd=root,par=root;nd;) {
		par=nd;
		intersect(nd->arc.ind,i);
		if(ArcLeft(nd->arc,c[i].x,c[i].y-c[i].r))
			s=1,nd=nd->right;
		else s=0,nd=nd->left;
	}
	arcs[0][i]=n1=NewNode(arc_t(i,0));
	arcs[1][i]=n2=NewNode(arc_t(i,1));

	n2->par=n1;
	n1->right=n2;
	n1->par=par;
	if(par) {
		if(s==0)par->left=n1;
		else par->right=n1;
	}
	else root=n1;
	if(n1->prev())intersect(n1->arc.ind,n1->prev()->arc.ind);
	if(n2->next())intersect(n2->arc.ind,n2->next()->arc.ind);
}

bool CheckTree(node_t *nd) {
	if(nd->left) {
		if(nd->left->par!=nd||!CheckTree(nd->left))return 0;
	}
	if(nd->right) {
		if(nd->right->par!=nd||!CheckTree(nd->right))return 0;
	}
	return true;
}

inline void LeftRotate(node_t *x) {
	node_t *y=x->right;
	y->par=x->par;
	if(y->par)y->par->replace(x,y);
	else root=y;
	x->right=y->left;
	if(x->right)x->right->par=x;
	x->par=y;
	y->left=x;
}

inline void RightRotate(node_t *x) {
	node_t *y=x->left;
	y->par=x->par;
	if(y->par)y->par->replace(x,y);
	else root=y;
	x->left=y->right;
	if(x->left)x->left->par=x;
	x->par=y;
	y->right=x;
}


inline void EraseNode(node_t *nd) {
	while(nd->left||nd->right) {
		if(nd->right)LeftRotate(nd);
		else RightRotate(nd);
	}

	if(nd->par)nd->par->replace(nd,0);
	else root=0;
}

inline void EraseCircle(int i) {
	node_t *n1,*n2,*n3,*n4;
	int i1,i2,j1,j2;
	if(arcs[0][i]->prev())i1=arcs[0][i]->prev()->arc.ind;
	else i1=-1;
	if(arcs[1][i]->prev())i2=arcs[1][i]->prev()->arc.ind;
	else i2=-1;
	if(arcs[0][i]->next())j1=arcs[0][i]->next()->arc.ind;
	else j1=-1;
	if(arcs[1][i]->next())j2=arcs[1][i]->next()->arc.ind;
	else j2=-1;
	if(i1>=0&&j1>=0)intersect(i1,j1);
	if(i2>=0&&j1>=0)intersect(i2,j1);	
	if(i1>=0&&j2>=0)intersect(i1,j2);
	if(i2>=0&&j2>=0)intersect(i2,j2);

	EraseNode(arcs[0][i]);
	EraseNode(arcs[1][i]);
}

int main() {
	int n,i,j;

	fscanf(ifs,"%d",&n);
	
	srand(n^24125+24412);

	for(i=0;i<n;i++) {
		fscanf(ifs,"%d%d%d",&c[i].x,&c[i].y,&c[i].r);
		ev[2*i]=event_t(c[i].y-c[i].r,0,i);
		ev[2*i+1]=event_t(c[i].y+c[i].r,1,i);
	}
	sort(ev,ev+2*n);
	for(i=0;i<2*n;i++) {
//		fprintf(stderr,"ev[%d]={%d,%d,%d}\n",i,ev[i].y,ev[i].type,ev[i].ind);
		if(ev[i].type==0)InsertCircle(ev[i].ind);
		else EraseCircle(ev[i].ind);
//		if(!CheckTree(root))fprintf(stderr,"ERROR\n");
	}
	fprintf(ofs,"0\n");
	fclose(ifs);
	fclose(ofs);
	return 0;
}
