/* vc_cpp */
/*

 '  CIRCLES      (STL).

O(n log n)

*/
#include <vector>
#include <queue>
#include <set>
#include <cmath>
#include <fstream>
#include <iostream>

using namespace std;

#define eps 1e-9

FILE *fin = fopen("circles.dat", "r");
FILE *fout = fopen("circles.sol", "w");
int n;
int *x, *y, *r;
int A, B;

float height;

struct circle
{
    int y, x, r, key, id;
    int mask;

    circle()
    {
    }

    circle (int Id, int X, int Y, int R, int Mask = 0, int Key = 0)
    {
        id = Id; x = X; y = Y; r = R; mask = Mask; key = Key;
    }

    inline float value ()
    {
        float R, D;
        R = fabs(height - y);
        D = sqrt(r*r - R*R);

        if (mask == 1) // left
            return x - D;
        else if (mask == 2)
            return x + D;

        return -1;
    }
};

struct less_queue
{
    bool operator() (circle a, circle b)
    {
        if (abs(a.key-b.key) < eps)
        {
            if (abs(a.x - b.x) < eps)
            {
                return a.mask > b.mask;
            }
            return a.x < b.x;
        }
        return a.key < b.key;
    }
};

struct less_set
{
    bool operator() (circle a, circle b) const
    {
        float xa, xb;
        xa = a.value();
        xb = b.value();

        if (fabs(xa - xb) < eps)
            return false;
        return xa < xb;
    }
};

priority_queue<circle, vector<circle>, less_queue> q;
multiset<circle, less_set> inter;

#define SQR(x) ((x)*(x))
inline void intersect(int i,int j) {
     int d2=SQR(x[i]-x[j])+SQR(y[i]-y[j]);
     if(d2<=SQR(r[i]+r[j])&&d2>=SQR(r[i]-r[j]))
	 {
		 fprintf(fout,"%d %d\n", i+1, j+1);
		 fclose(fout);
		 exit(0);
	 }
}

void solve()
{
    int i;
    for (i = 0; i < n; ++i)
    {
        q.push( circle( i, x[i], y[i], r[i], 1, y[i]+r[i] ) );
        q.push( circle( i, x[i], y[i], r[i], 2, y[i]-r[i] ) );
    }

    circle c;
    multiset<circle, less_set>::iterator low, up, temp;

    while ( !q.empty() && (A<0 || B<0))
    {
        c = q.top(); q.pop();
        height = c.key;
        //cout << height << endl;

        if (c.mask == 1)
        {
            //create new    
            low = inter.lower_bound(c);
            up = inter.upper_bound(c);
            if (low != inter.end())
                intersect(c.id, low->id);
            if (up != inter.end())
                intersect(c.id, up->id);
            if (inter.size())
            {
                up--;
                if (up != inter.end())
                    intersect(c.id, up->id);
            }


            c.mask = 1;
            inter.insert(c);
            c.mask = 2;
            inter.insert(c);
        }
        else if (c.mask == 2)
        {
            //erase old
            low = inter.lower_bound(c);
            up = inter.upper_bound(c);
            for (temp = low; temp != up;)
            {
                if (temp->id == c.id)
                {
                    low = temp;
                    temp ++;
                    inter.erase(low);
                }
                else
                    temp ++;
            }

            if (up != inter.end())
            {
                low = up;
                if (low != inter.begin())
                {
                    low --;
                    intersect(low->id, up->id);
                }
            }
        }
/*
        for (temp = inter.begin(); temp != inter.end(); ++temp)
        {
            cout << temp->value() << " (" << temp->r << ") ; ";
        }
        cout<<endl;
*/
    }
}

int main ()
{
    int i;

	fscanf(fin, "%d", &n);
	x = new int[n]; y = new int[n]; r = new int[n];
	for (i = 0; i < n; ++i)
	{
		fscanf(fin, "%d%d%d", &x[i], &y[i], &r[i]);
	}

    A = B = -1;
    solve();

//    if (A >= 0 && B >= 0)
//        ofs << A+1 << " " << B+1 << endl;
//    else
//        ofs << 0 << endl;
	fprintf(fout, "0\n");
	fclose(fin);
	fclose(fout);

	delete x; delete y; delete r;
	return 0;
}